| Title: | Interactive Shiny Presentation for Working with Multinomial Logistic Regression |
|---|---|
| Description: | An interactive presentation on the topic of Multinomial Logistic Regression. It is helpful to those who want to learn Multinomial Logistic Regression quickly and get a hands on experience. The presentation has a template for solving problems on Multinomial Logistic Regression. Runtime examples are provided in the package function as well as at <https://jarvisatharva.shinyapps.io/MultinomPresentation>. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-21 06:44:10 UTC |
| Source: | https://github.com/cran/MNLR |
MNLR() loads interactive user interface built using R shiny.
MNLR()MNLR()
Start MNLR
The interactive user interface is to provide an easy way for people who are learning Multinomial Logistic Regression. Includes example data for testing out a few example analysis.
Nothing
if(interactive()){ library(rmarkdown) MNLR() }if(interactive()){ library(rmarkdown) MNLR() }